import React, { useContext, useState } from 'react'
import { AuthContext } from '../../store/auth'
import Button from '../button'
import { TelegramLogo, CopyIcon } from '../icons'
import Styles from './TelegramBot.module.css'

const TelegramBot = () => {
  const [isCopiedTag, setIsCopiedTag] = useState({
    isCopied: false,
    isError: false,
    message: ''
  })
  const { isAuthenticated, authState } = useContext(AuthContext)
  const isAuth = isAuthenticated()
  const { isCopied, isError, message } = isCopiedTag
  const { isTelegramConnected } = isAuth ? authState.userInfo : ''
  const onClick = () => {
    navigator.clipboard.writeText('probexpertbot').then(
      () => {
        setIsCopiedTag({
          isCopied: true,
          isError: false,
          message: 'Copied!'
        })
      },
      () => {
        setIsCopiedTag({
          isCopied: false,
          isError: true,
          message: 'Error!'
        })
      }
    )
  }
  return (
    <div className={Styles.telegram_bot_container}>
      <div className={Styles.telegram_bot_title}>
        Use ProbExpert Telegram bot
      </div>
      <a href="https://t.me/probexpertbot" target="_blank">
        <TelegramLogo className={Styles.telegram_bot_logo} />
      </a>
      {isAuth ? (
        !isTelegramConnected ? (
          <Button href="/telegram/connect" primary full>
            Connect Telegram with ProbExpert
          </Button>
        ) : (
          <>
            <div className={Styles.telegram_bot_tag}>
              <span>@probexpertbot</span>{' '}
              <CopyIcon
                className={Styles.telegram_bot_tag_icon}
                onClick={onClick}
              />
            </div>
            {isCopied ? (
              <div className={Styles.telegram_bot_tag_copied}>{message}</div>
            ) : (
              isError && (
                <div className={Styles.telegram_bot_tag_error}>{message}</div>
              )
            )}
          </>
        )
      ) : (
        <div>Sign in to use the telegram bot</div>
      )}
    </div>
  )
}

export default TelegramBot
